@@ -30,6 +30,7 @@ my $delay            = 3;
 my $nosplash         = FALSE;
 my $show_names       = FALSE;
 my $noaccel          = FALSE;
+my $ignore_x         = FALSE;
 my $heads            = 1;
 my $threads          = Sys::CPU::cpu_count() * 2;
 my $RUNNING : shared = TRUE;
@@ -51,6 +52,7 @@ GetOptions(
     'noaccel'      => \$noaccel,
     'threads=i'    => \$threads,
     'names'        => \$show_names,
+	'ignore-x-windows' => \$ignore_x,
 );
 my @paths : shared = @ARGV;
 
@@ -498,6 +500,7 @@ sub show {
           'SPLASH'      => $display,
           'SIMULATED_X' => $nx,
           'SIMULATED_Y' => $ny,
+		  'IGNORE_X_WINDOWS' => $ignore_x,
       )
       :
       Graphics::Framebuffer->new(
@@ -506,6 +509,7 @@ sub show {
           'SPLASH'      => $splash,
           'FB_DEVICE'   => $dev,
           'SPLASH'      => $display,
+		  'IGNORE_X_WINDOWS' => $ignore_x,
       );
     local $SIG{'ALRM'} = local $SIG{'INT'}  = local $SIG{'QUIT'} = local $SIG{'KILL'} = local $SIG{'TERM'} = local $SIG{'HUP'} = undef;
 
