@@ -14,22 +14,25 @@ use Getopt::Long;
 exit(0) unless(scalar(@ARGV));
 my $file = $ARGV[-1];
 
-my $full    = FALSE;
-my $noclear = FALSE;
-my $delay   = 10;
-my $alpha   = 255;
+my $full     = FALSE;
+my $noclea r = FALSE;
+my $ignore_x = FALSE;
+my $delay    = 10;
+my $alpha    = 255;
 
 GetOptions(
     'full'    => \$full,
     'wait=i'  => \$delay,
     'noclear' => \$noclear,
     'alpha=i' => \$alpha,
+	'ignore-x-windows' => \$ignore_x,
 );
 
 our $f = Graphics::Framebuffer->new(
     'SPLASH'      => FALSE,
     'SHOW_ERRORS' => FALSE,
     'RESET'       => 1 - $noclear,
+	'IGNORE_X_WINDOWS' => $ignore_x,
 );
 
 $SIG{'KILL'} = $SIG{'QUIT'} = $SIG{'INT'} = $SIG{'HUP'} = sub { $f->text_mode(); exec('reset'); };
